<?php $TRANSLATIONS = array(
"Music" => "Μουσική",
"songs" => "τραγούδια",
"albums" => "άλμπουμ",
"Add to playlist" => "Προσθήκη στην λίστα αναπαραγωγής",
"Add album to playlist" => "Προσθήκη άλμπουμ στην λίστα αναπαραγωγής",
"Play" => "Αναπαραγωγή",
"Pause" => "Παύση",
"Previous" => "Προηγούμενο",
"Next" => "Επόμενο",
"Mute" => "Σίγαση",
"Unmute" => "Επαναφορά ήχου",
"Rescan Collection" => "Επανασάρωση συλλογής",
"Artist" => "Καλλιτέχνης",
"Album" => "Άλμπουμ",
"Title" => "Τίτλος",
"Media" => "Πολυμέσα",
"Ampache address:" => "Διεύθυνση Ampache:"
);
